``binarymap`` documentation
===================================================

``binarymap`` is a Python package written by `the Bloom lab <https://research.fhcrc.org/bloom/en.html>`_.

The package is designed to convert protein / nucleotide sequences into binary representations.

See below for information and examples of how to use this package.

Contents
----------
.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 2

   installation
   binarymap
   package_index
   acknowledgments
